Split out isrg from ssr and reorient build graph to make interpreter build 2x faster (#2969)

* split out isrg and core-types to speed up interpreter build
This commit is contained in:
Jonathan Kelley authored and GitHub committed 2024-09-16 16:49:06 -07:00
1 parent f0d814fede
commit 143ad749ea
28 files changed
+197 -231

No files matched your search

+2 -6
View File
@@ -14,7 +14,8 @@ resolver = "2"
dioxus-fullstack = { workspace = true }
dioxus-lib.workspace = true
dioxus-router = { workspace = true, features = ["fullstack"]}
dioxus-ssr = { workspace = true, features = ["incremental"], optional = true }
dioxus-ssr = { workspace = true, optional = true }
dioxus-isrg = { workspace = true, optional = true }
axum = { workspace = true, features = ["ws", "macros"], optional = true }
tower-http = { workspace = true, features = ["fs"], optional = true }
dioxus-hot-reload = { workspace = true, features = ["serve"], optional = true }
@@ -34,10 +35,5 @@ default = []
server = ["dioxus-fullstack/server", "dioxus-router/ssr", "dep:dioxus-ssr", "dep:tokio", "dep:http", "dep:axum", "dep:tower-http", "dep:dioxus-hot-reload", "dep:dioxus-cli-config", "dep:tower"]
web = ["dioxus-fullstack/web", "dioxus-router/web", "dep:dioxus-web"]
# [[bench]]
# name = "incremental"
# required-features = ["server"]
# harness = false
[package.metadata.docs.rs]
cargo-args = ["-Zunstable-options", "-Zrustdoc-scrape-examples"]